@@ -79,7 +79,7 @@ class BlacklistEntry(Base):
     def __str__(self):
         txt = f"Blacklist Entry #{self.id}: "
         for key, value in self.to_dict().items():
-            if key == "id":
+            if key == "id" or key == "entry_type":
                 continue
             txt += f"{key}={value} "
         return txt
@@ -124,11 +124,12 @@ class WhitelistEntry(Base):
     def __str__(self):
         txt = f"Whitelist Entry #{self.id}: "
         for key, value in self.to_dict().items():
-            if key == "id":
+            if key == "id" or key == "entry_type":
                 continue
             txt += f"{key}={value} "
         return txt
 
+
 # Dependency
 @contextlib.contextmanager
 def get_db_session():
@@ -200,7 +201,7 @@ def delete_infrastructure_context(db: Session, context_id: int):
     if not query.count():
         LOGGER.warning(f"no infrastructure context found by id: {context_id}")
         return False
-    LOGGER.warning(f"deleting {query.one()} Blacklist entries.")
+    LOGGER.warning(f"deleting: {query.one()}")
     query.delete()
     db.commit()
     return True
@@ -342,7 +343,7 @@ def remove_from_blacklist(
     if reference is not None:
         criteria.append(BlacklistEntry.reference == reference)
     bl_query = bl_query.filter(or_(*criteria))
-    LOGGER.debug(f"query: {bl_query}")
+    #LOGGER.debug(f"query: {bl_query}")
     if not bl_query.count():
         LOGGER.debug(f"no blacklist entries found for deletion.")
         return None
@@ -399,7 +400,7 @@ def remove_from_whitelist(
     if reference is not None:
         criteria.append(WhitelistEntry.reference == reference)
     wl_query = wl_query.filter(or_(*criteria))
-    LOGGER.debug(f"query: {wl_query}")
+    #LOGGER.debug(f"query: {wl_query}")
     if not wl_query.count():
         LOGGER.debug(f"no whitelist entries found for deletion.")
         return None
@@ -453,7 +454,7 @@ def check_blacklist(
     if country is not None:
         criteria.append(BlacklistEntry.country == country)
     bl_query = bl_query.filter(or_(*criteria))
-    LOGGER.debug(f"query: {bl_query}")
+    #LOGGER.debug(f"query: {bl_query}")
     return bl_query.all()
 
 
@@ -499,7 +500,7 @@ def check_whitelist(
     if country is not None:
         criteria.append(WhitelistEntry.country == country)
     wl_query = wl_query.filter(or_(*criteria))
-    LOGGER.debug(f"query: {wl_query}")
+    #LOGGER.debug(f"query: {wl_query}")
     return wl_query.all()
 
 
